=========================
WWW Utilities for Tendril
=========================

.. image:: https://img.shields.io/travis/chintal/tendril-utils-www.svg
        :target: https://travis-ci.org/chintal/tendril-utils-www

.. image:: https://img.shields.io/pypi/v/tendril-utils-www.svg
        :target: https://pypi.python.org/pypi/tendril-utils-www

* License: AGPLv3
* Documentation: http://tendril-utils-www.readthedocs.org


Internet utilities for Tendril.
